@@ -19,12 +19,9 @@
 #ifndef __DICTIONARY_SET_H_
 #define __DICTIONARY_SET_H_
 
-#include "utils.h"
-#include "dictionary_group.h"
+#include "common.h"
 
-typedef void * dictionary_set_t;
-
-dictionary_set_t dictionary_set_open(void);
+dictionary_set_t dictionary_set_open(config_t config);
 
 void dictionary_set_close(dictionary_set_t t_dictionary);
 
@@ -34,4 +31,6 @@ dictionary_group_t dictionary_set_get_group(dictionary_set_t t_dictionary, size_
 
 size_t dictionary_set_count_group(dictionary_set_t t_dictionary);
 
+config_t dictionary_set_get_config(dictionary_set_t t_dictionary);
+
 #endif /* __DICTIONARY_SET_H_ */
